local toc, data = ...
local AddonId = toc.identifier

-- Local config options ---------------------------------------------------------
local scale = 0.5
local healthBarWidth = 128 * scale
local healthBarHeight = 256 * scale
---------------------------------------------------------------------------------

-- Frame Configuration Options --------------------------------------------------
local HealthBar = WT.UnitFrame:Template("HealthBar")
HealthBar.Configuration.Name = "Health Bar Unit Frame"
HealthBar.Configuration.RaidSuitable = false
HealthBar.Configuration.FrameType = "Frame"
HealthBar.Configuration.Width = healthBarWidth
HealthBar.Configuration.Height = healthBarHeight
HealthBar.Configuration.Resizable = { healthBarWidth, healthBarHeight, 256, 512 }
---------------------------------------------------------------------------------


function HealthBar:Construct(options)

	local template =
	{
		elements = 
		{
			{
				id="frameBackdrop", type="Frame", parent="frame", layer=0,
				attach = 
				{ 
					{ point="TOPLEFT", element="frame", targetPoint="TOPLEFT" },
					{ point="BOTTOMRIGHT", element="frame", targetPoint="BOTTOMRIGHT" } 
				}, 				
				visibilityBinding="id",
				texAddon = AddonId, texFile = "img/wtMiniFrame_bg.png", alpha=0.5,
				color={r=0,g=0,b=0,a=0.3},
			},
			{
				id="barHealth", type="Bar", parent="frameBackdrop", layer=10,
				attach = {
					{ point="TOPLEFT", element="frame", targetPoint="TOPLEFT" },
					{ point="BOTTOMRIGHT", element="frame", targetPoint="BOTTOMRIGHT" },
				},
				growthDirection="up",
				binding="healthPercent", colorBinding="callingColor",
				texAddon=AddonId, texFile="img/WinBrH.png", 
				backgroundColor={r=0, g=0, b=0, a=0.7}
			},
			{
				id="frameBlocked", type="Frame", parent="frameBackdrop", layer=15, alpha=0.3,
				attach = 
				{ 
					{ point="TOPLEFT", element="frame", targetPoint="TOPLEFT" },
					{ point="BOTTOMRIGHT", element="frame", targetPoint="BOTTOMRIGHT" } 
				},
				colorBinding="callingColor", 
			},
			{
				id="barAbsorbTop", type="Bar", parent="frameBackdrop", layer=15,
				attach = {
					{ point="TOPLEFT", element="frame", targetPoint={0.08,0} },
					{ point="BOTTOMRIGHT", element="frame", targetPoint={0.92,0.04} },
				},
				growthDirection="up",
				binding="absorbPercentTop",
				color={r=0.08, g=0.91, b=1, a=0.9},
				backgroundColor={r=0.08, g=0.91, b=1, a=0}
			},
			{
				id="barAbsorbLeft", type="Bar", parent="frameBackdrop", layer=15,
				attach = {
					{ point="TOPLEFT", element="frame", targetPoint="TOPLEFT" },
					{ point="BOTTOMRIGHT", element="frame", targetPoint={0.08,1} },
				},
				growthDirection="up",
				binding="absorbPercent",
				color={r=0.08, g=0.91, b=1, a=0.9},
				backgroundColor={r=0.08, g=0.91, b=1, a=0}
			},
			{
				id="barAbsorbRight", type="Bar", parent="frameBackdrop", layer=15,
				attach = {
					{ point="TOPRIGHT", element="frame", targetPoint="TOPRIGHT" },
					{ point="BOTTOMLEFT", element="frame", targetPoint={0.92,1} },
				},
				growthDirection="up",
				binding="absorbPercent",
				color={r=0.08, g=0.91, b=1, a=0.9},
				backgroundColor={r=0.08, g=0.91, b=1, a=0}
			},
			{
				id="barAbsorbBottom", type="Bar", parent="frameBackdrop", layer=15,
				attach = {
					{ point="TOPLEFT", element="frame", targetPoint={0.08,0.96} },
					{ point="BOTTOMRIGHT", element="frame", targetPoint={0.92,1} },
				},
				growthDirection="up",
				binding="absorbPercentBottom",
				color={r=0.08, g=0.91, b=1, a=0.9},
				backgroundColor={r=0.08, g=0.91, b=1, a=0}
			},
			{
				id="labelHealthPercent", type="Label", parent="frame", layer=14,
				attach = 
				{ 
					{ point="CENTER", element="frame", targetPoint="CENTER" },
				}, visibilityBinding="id", text="{healthPercent}%",fontSize=24,
				color={r=1,g=1,b=1,a=1},
			}, 
			{
				id="labelHealthAndAbsorbPercent", type="Label", parent="frame", layer=14,
				attach = 
				{ 
					{ point="TOPCENTER", element="labelHealthPercent", targetPoint="BOTTOMCENTER" },
				}, 
				visibilityBinding="id", text="{healthAbsorbPercent}%", fontSize=15,
				color={r=0.08, g=0.91, b=1, a=1},
			}, 
			{
				id="labelHealthMax", type="Label", parent="frame", layer=18,
				attach = 
				{ 
					{ point="BOTTOMCENTER", element="barHealth", targetPoint="BOTTOMCENTER", offsetX=0, offsetY=0 },
				}, visibilityBinding="id", text="{healthMax}",fontSize=24,
				color={r=1,g=1,b=1,a=1},
			},
			{
				id="labelHealth", type="Label", parent="frame", layer=18,
				attach = 
				{ 
					{ point="TOPCENTER", element="barHealth", targetPoint="TOPCENTER", offsetX=0, offsetY=0 },
				}, visibilityBinding="id", text="{health}",fontSize=24,
				color={r=1,g=1,b=1,a=1},
			}, 
			{
				id="labelAbsorb", type="Label", parent="frame", layer=14,
				attach = 
				{ 
					{ point="TOPCENTER", element="labelHealth", targetPoint="BOTTOMCENTER" },
				}, 
				visibilityBinding="id", text="{absorb}", fontSize=15,
				color={r=0.08, g=0.91, b=1, a=1},
			}, 
		}
	}
	
	for idx,element in ipairs(template.elements) do
		local showElement = true
		if not options.showAbsorb and (element.id=="barAbsorbTop" or element.id=="barAbsorbRight" or 
		element.id=="barAbsorbLeft" or element.id=="barAbsorbBottom" or element.id=="labelHealthAndAbsorbPercent") then showElement = false end
		if showElement then
			self:CreateElement(element)
		end 
	end
	
	self:SetSecureMode("restricted")
	self:SetMouseoverUnit(self.UnitSpec)
	self.Event.LeftClick = "target @" .. self.UnitSpec
	self.Event.RightClick = function() if self.UnitId then Command.Unit.Menu(self.UnitId) end end
	
end

WT.Unit.CreateVirtualProperty("absorbPercentTop", { "absorb", "healthMax" },
	function(unit)
		if unit.absorb and unit.healthMax and unit.healthMax > 0 then
			local absorb = (unit.absorb / unit.healthMax) * 100
			if absorb > 96 and absorb < 100 then
				absorb = ((absorb-96)/4)*100
				return absorb
			elseif absorb > 100 then
				return 100
			else
				return nil
			end
		else 
			return nil
		end 
	end)
	
WT.Unit.CreateVirtualProperty("absorbPercentBottom", { "absorb", "healthMax" },
	function(unit)
		if unit.absorb and unit.healthMax and unit.healthMax > 0 then
			local absorb = (unit.absorb / unit.healthMax) * 100
			if absorb < 4 and absorb > 0 then
				absorb = (absorb/4)*100
				return absorb
			elseif absorb > 4 then
				return 100
			else
				return nil
			end
		else 
			return nil
		end 
	end)